@@ -1,5 +1,9 @@
 #!/bin/bash
 
+# avoid git "dubious ownership" error
+echo "git: setting $PROJECT_SOURCE_DIR as safe directory"
+git config --global --add safe.directory $PROJECT_SOURCE_DIR
+
 if [ "$OS" == "win10" ]; then
     # there is no docker on windows
     CONTAINER_ID=0
