@@ -1,6 +1,12 @@
 #!/bin/bash
 
+# Path needs to use forward slashes
+# This is ok on Linux but since gitlab-runner 11.7 on windows all path variables use backward slash instead of forward slash
+# → Replace all backslash to forward slash 
+export PROJECT_SOURCE_DIR=${PROJECT_SOURCE_DIR//\\//}
+
 echo "Job $CI_JOB_NAME"
+echo "PROJECT_SOURCE_DIR=$PROJECT_SOURCE_DIR"
 
 if ! grep -q TRIGGER_STAGE_COVERAGE "${PROJECT_LOG_DIR}/trigger-stage.txt"; then
     echo "Job skipped as /coverage flag not in commit message and CAMITK_CI_STAGE < $STAGE_CONFIGURE"; 
