@@ -29,7 +29,8 @@ if [[ "$OS" != "win10" ]]; then
     export DISPLAY=":98"
     # create a specific file for xauth
     export XAUTHORITY=$(mktemp)
-    Xvfb $DISPLAY -screen 0 1280x1024x16 +iglx -ac -nolisten tcp -nolisten unix -auth $XAUTHORITY & > >(tee --append ${PROJECT_LOG_DIR}/test.log) 2>&1
+    # remove +iglx for now 
+    Xvfb $DISPLAY -screen 0 1280x1024x16 -ac -nolisten tcp -nolisten unix -auth $XAUTHORITY & > >(tee --append ${PROJECT_LOG_DIR}/test.log) 2>&1
     trap "trap - SIGTERM && kill -- -$$" SIGINT SIGTERM EXIT
     # give some times to start the Xvfb
     sleep 10
@@ -42,6 +43,7 @@ fi
 echo "===== Running ctest ====="
 
 ctest --extra-verbose \
+      --output-on-failure \
       -DCTEST_SITE="$CDASH_SITE" \
       -DCI_MODE="$CAMITK_CI_MODE" \
       -DCI_ID="P $CI_PIPELINE_ID - J $CI_BUILD_ID" \
@@ -105,6 +107,7 @@ if grep --quiet "Fatal error" $CI_PROJECT_DIR/$PROJECT_LOG_DIR/ci-test.log; then
         
         echo "Exact command:"  >> ${PROJECT_LOG_DIR}/rerun-test.log
         echo "ctest --extra-verbose \
+              --output-on-failure \
               -DCTEST_SITE=\"$CDASH_SITE\" \
               -DCI_MODE=\"$CAMITK_CI_MODE\" \
               -DCI_ID=\"P $CI_PIPELINE_ID - J $CI_BUILD_ID\" \
@@ -118,6 +121,7 @@ if grep --quiet "Fatal error" $CI_PROJECT_DIR/$PROJECT_LOG_DIR/ci-test.log; then
 
         echo "Re-run test result:" > >(tee --append ${PROJECT_LOG_DIR}/rerun-test.log) 2>&1
         ctest --extra-verbose \
+              --output-on-failure \
               -DCTEST_SITE="$CDASH_SITE" \
               -DCI_MODE="$CAMITK_CI_MODE" \
               -DCI_ID="P $CI_PIPELINE_ID - J $CI_BUILD_ID" \
