@@ -7,11 +7,11 @@
 #include <OpenAction.h>
 #include <OpenFile.h>
 #include <QuitAction.h>
-#include <RemoveLastInstanciatedAction.h>
+#include <RemoveLastInstantiatedAction.h>
 #include <SaveAction.h>
 #include <SaveAllAction.h>
 #include <SaveAsAction.h>
-#include <SelectLastInstanciatedAction.h>
+#include <SelectLastInstantiatedAction.h>
 #include <SetPathToTestData.h>
 #include <Show3DViewer.h>
 #include <ShowAllViewers.h>
