@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -27,20 +27,26 @@
 
 #include "OpenAction.h"
 #include "OpenFile.h"
+#include "OpenWorkspace.h"
+#include "OpenWorkspaceAction.h"
 #include "SaveAction.h"
 #include "CloseAction.h"
 #include "CloseAllAction.h"
 #include "SaveAsAction.h"
 #include "SaveAllAction.h"
+#include "SaveWorkspace.h"
 #include "QuitAction.h"
 
 // --------------- init -------------------
 void ApplicationFileActionExtension::init() {
     registerNewAction(OpenAction);
     registerNewAction(OpenFile);
+    registerNewAction(OpenWorkspaceAction);
+    registerNewAction(OpenWorkspace);
     registerNewAction(SaveAction);
     registerNewAction(SaveAsAction);
     registerNewAction(SaveAllAction);
+    registerNewAction(SaveWorkspace);
     registerNewAction(CloseAction);
     registerNewAction(CloseAllAction);
     registerNewAction(QuitAction);
