@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -43,7 +43,7 @@ CloseAction::CloseAction(ActionExtension* extension) : Action(extension) {
     addTag(tr("Close"));
 
     // add shortcut
-    getQAction()->setShortcut(QKeySequence::Close);
+    getQAction()->setShortcuts({QKeySequence::Close, QKeySequence::Delete});
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
 }
 
