@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -82,7 +82,8 @@ Action::ApplyStatus OpenAction::apply() {
     if (!files.isEmpty()) {
         QStringList listOfFiles = files; // as stated by the Qt doc (although without further information): "If you want to iterate over the list of files, you should iterate over a copy."
         QStringList::const_iterator fileIterator = listOfFiles.constBegin();
-        while (fileIterator != listOfFiles.constEnd() && Application::open(*fileIterator) != nullptr) {
+        while (fileIterator != listOfFiles.constEnd()) {
+            Application::open(*fileIterator);
             ++fileIterator;
         }
         if (fileIterator == listOfFiles.constEnd()) {
