@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -67,7 +67,11 @@ QWidget* SaveAsAction::getWidget() {
 
 // --------------- apply -------------------
 Action::ApplyStatus SaveAsAction::apply() {
-    Component* comp = Application::getSelectedComponents().last();
+    Component* comp = getTargets().last();
+    if (!Application::isAlive(comp)) {
+        CAMITK_ERROR("SaveAsAction was called to save an invalid Component");
+        return ERROR;
+    }
 
     Application::showStatusBarMessage(tr("Saving currently selected component under new filename or format..."));
 
@@ -175,12 +179,17 @@ Action::ApplyStatus SaveAsAction::apply() {
     filterList.sort();
     QString test = filterList.join(";;");
 
-    QFileDialog saveFileDialog(nullptr, tr("Save File As..."), QFileInfo(compfileName).dir().canonicalPath() + "/" + suggestedName, test);
-    saveFileDialog.setFileMode(QFileDialog::AnyFile);
-    saveFileDialog.setOption(QFileDialog::HideNameFilterDetails, false);
+    // Guess the directory we want to save in
+    QString directory;
+    if (compfileName.isEmpty()) {
+        directory = Application::getLastUsedDirectory().absolutePath();
+    }
+    else {
+        directory = QFileInfo(compfileName).dir().canonicalPath();
+    }
 
     // get the file name
-    QString filename = QFileDialog::getSaveFileName(nullptr, tr("Save File As..."), QFileInfo(compfileName).dir().canonicalPath() + "/" + suggestedName, test);
+    QString filename = QFileDialog::getSaveFileName(nullptr, tr("Save File As..."), directory + "/" + suggestedName, test, nullptr, QFileDialog::Option());
 
     if (!filename.isEmpty()) {
         // rename the filename of the component and save
