@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -29,6 +29,7 @@
 #include <Property.h>
 #include <MedicalImageViewer.h>
 #include <ImageComponent.h>
+#include <Log.h>
 
 // to get the enum as a string
 #include <QMetaEnum>
@@ -102,13 +103,19 @@ QWidget* AnglesAndTranslationAction::getWidget() {
     // update the pointer
     currentImageComp = dynamic_cast<ImageComponent*>(getTargets().last())->getArbitrarySlices();
 
-    // make sure the arbitrary slice is visible in 3D
-    currentImageComp->setVisibility("3D Viewer", true);
+    if (currentImageComp == nullptr) {
+        CAMITK_WARNING(tr("Arbitrary Slice manipulation is not possible on 2D images. Aborting."))
+        return nullptr;
+    }
+    else {
+        // make sure the arbitrary slice is visible in 3D
+        currentImageComp->setVisibility("3D Viewer", true);
 
-    // update the properties
-    update();
+        // update the properties
+        update();
 
-    return actionWidget;
+        return actionWidget;
+    }
 }
 
 // ---------------------- updateParameters ----------------------------
