@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -32,7 +32,6 @@
 #include <ImageComponent.h>
 #include <Application.h> // to get the action widget size before this widget is painted
 #include <Viewer.h>
-#include <Log.h>
 
 // -- QT stuff
 #include <QGraphicsTextItem>
@@ -91,7 +90,7 @@ void ImageLutWidget::updateComponent(camitk::ImageComponent* imageComponent) {
     // if there is no lookup table, just don't display this widget!
     if (myComponent->getLut() == nullptr) {
         setEnabled(false);
-        return;
+        throw (AbortException("No LUT in this ImageComponent. Aborting\n"));
     }
     else {
         setEnabled(true);
