@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -34,10 +34,8 @@
 // -- CamiTK Core stuff
 #include <MainWindow.h>
 #include <Application.h>
-#include <MedicalImageViewer.h>
 #include <Core.h>
 #include <ExtensionManager.h>
-#include <Explorer.h>
 #include <Log.h>
 
 using namespace camitk;
@@ -128,7 +126,7 @@ ActionStateMachine::ActionStateMachine(int& argc, char** argv, QString inputFile
     (*logStream) << " * $CAMITK_LICENCE_BEGIN$" << Qt::endl;
     (*logStream) << " *" << Qt::endl;
     (*logStream) << " * CamiTK - Computer Assisted Medical Intervention ToolKit" << Qt::endl;
-    (*logStream) << " * (c) 2001-2020 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)" << Qt::endl;
+    (*logStream) << " * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France" << Qt::endl;
     (*logStream) << " *" << Qt::endl;
     (*logStream) << " * Visit http://camitk.imag.fr for more information" << Qt::endl;
     (*logStream) << " *" << Qt::endl;
@@ -557,7 +555,7 @@ void ActionStateMachine::autoNext() {
 void ActionStateMachine::initMainWindow() {
 
     mainWindow = new MainWindow(name);
-    MedicalImageViewer* medicalImageViewer = dynamic_cast<MedicalImageViewer*>(Application::getViewer("Medical Image Viewer"));
+    Viewer* medicalImageViewer = Application::getViewer("Medical Image Viewer");
     if (medicalImageViewer != nullptr) {
         mainWindow->setCentralViewer(medicalImageViewer);
     }
@@ -566,7 +564,7 @@ void ActionStateMachine::initMainWindow() {
         return;
     }
     mainWindow->addDockViewer(Qt::RightDockWidgetArea, Application::getViewer("Action State Viewer"));
-    Explorer* explorer = dynamic_cast<Explorer*>(Application::getViewer("Explorer"));
+    Viewer* explorer = Application::getViewer("Explorer");
     if (explorer != nullptr) {
         mainWindow->addDockViewer(Qt::LeftDockWidgetArea, explorer);
     }
@@ -576,7 +574,7 @@ void ActionStateMachine::initMainWindow() {
     }
 
     // never show the toolbar
-    medicalImageViewer->setToolbarAutoVisibility(false);
+    medicalImageViewer->setToolBarVisibility(false);
 
     mainWindow->showStatusBar(true);
     this->setMainWindow(mainWindow);
