@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,11 +31,6 @@
 #include <ExtensionManager.h>
 #include <SettingsDialog.h>
 #include <Component.h>
-#include <MedicalImageViewer.h>
-#include <Explorer.h>
-#include <FrameExplorer.h>
-#include <PropertyExplorer.h>
-#include <ActionViewer.h>
 #include <Action.h>
 #include <Viewer.h>
 #include <Core.h> // for getActionDirectories()
@@ -74,7 +69,7 @@ ImpMainWindow::ImpMainWindow() : MainWindow("imp") {
     updateActionStates();
 
     // now add the different viewers
-    MedicalImageViewer* medicalImageViewer = dynamic_cast<MedicalImageViewer*>(Application::getViewer("Medical Image Viewer"));
+    Viewer* medicalImageViewer = Application::getViewer("Medical Image Viewer");
 
     if (medicalImageViewer != nullptr) {
         setCentralViewer(medicalImageViewer);
@@ -83,7 +78,7 @@ ImpMainWindow::ImpMainWindow() : MainWindow("imp") {
         CAMITK_ERROR(tr("Cannot find \"Medical Image Viewer\". This viewer is mandatory for running camitk-imp."))
     }
 
-    Explorer* explorer = dynamic_cast<Explorer*>(Application::getViewer("Explorer"));
+    Viewer* explorer = Application::getViewer("Explorer");
 
     if (explorer != nullptr) {
         addDockViewer(Qt::LeftDockWidgetArea, explorer);
@@ -92,7 +87,7 @@ ImpMainWindow::ImpMainWindow() : MainWindow("imp") {
         CAMITK_ERROR(tr("Cannot find \"Explorer\" viewer. This viewer is mandatory for running camitk-imp."))
     }
 
-    FrameExplorer* frameExplorer = dynamic_cast<FrameExplorer*>(Application::getViewer("Frame Explorer"));
+    Viewer* frameExplorer = Application::getViewer("Frame Explorer");
 
     if (frameExplorer != nullptr) {
         addDockViewer(Qt::LeftDockWidgetArea, frameExplorer);
@@ -101,7 +96,7 @@ ImpMainWindow::ImpMainWindow() : MainWindow("imp") {
         CAMITK_ERROR(tr("Cannot find \"Frame Explorer\" viewer. This viewer is mandatory for running camitk-imp."))
     }
 
-    PropertyExplorer* propertyExplorer = dynamic_cast<PropertyExplorer*>(Application::getViewer("Property Explorer"));
+    Viewer* propertyExplorer = Application::getViewer("Property Explorer");
 
     if (frameExplorer != nullptr) {
         addDockViewer(Qt::LeftDockWidgetArea, propertyExplorer);
@@ -110,11 +105,10 @@ ImpMainWindow::ImpMainWindow() : MainWindow("imp") {
         CAMITK_ERROR(tr("Cannot find \"Property Explorer\" viewer. This viewer is mandatory for running camitk-imp."))
     }
 
-    ActionViewer* actionViewer = dynamic_cast<ActionViewer*>(Application::getViewer("Action Viewer"));
+    Viewer* actionViewer = Application::getViewer("Action Viewer");
 
     if (actionViewer != nullptr) {
         addDockViewer(Qt::RightDockWidgetArea, actionViewer);
-        actionViewer->setSearchPanelVisible(true);
         showDockViewer(actionViewer, false);
     }
     else {
@@ -206,11 +200,13 @@ void ImpMainWindow::initActions() {
     //--- actions of the File menu
     // get the CamiTK actions
     fileOpen = Application::getAction("Open")->getQAction();
+    workspaceOpen = Application::getAction("Open Workspace File")->getQAction();
     fileClose = Application::getAction("Close")->getQAction();
     fileCloseAll = Application::getAction("Close All")->getQAction();
     fileSave = Application::getAction("Save")->getQAction();
     fileSaveAs = Application::getAction("Save As")->getQAction();
     fileSaveAll = Application::getAction("Save All")->getQAction();
+    workspaceSave = Application::getAction("Save Workspace")->getQAction();
     fileQuit = Application::getAction("Quit")->getQAction();
 
     recentDocumentSeparator = new QAction(tr("Recent Documents"), this);
@@ -281,6 +277,7 @@ void ImpMainWindow::initMenuBar() {
     // -- file
     fileMenu = new QMenu(tr("&File"));
     fileMenu->addAction(fileOpen);
+    fileMenu->addAction(workspaceOpen);
 
     updateOpenDirectoryMenu();
 
@@ -290,6 +287,7 @@ void ImpMainWindow::initMenuBar() {
     fileMenu->addAction(fileSave);
     fileMenu->addAction(fileSaveAs);
     fileMenu->addAction(fileSaveAll);
+    fileMenu->addAction(workspaceSave);
     fileMenu->addSeparator();
     fileMenu->addAction(saveHistory);
     fileMenu->addAction(recentDocumentSeparator);
