@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -100,20 +100,20 @@ const QString Core::getPaths() {
         globalDir = "[locally installed version: using user config directory as repository]";
     }
 
-    diagnosis << "- CamiTK version........................... " + QString(Core::version);
-    diagnosis << "- CamiTK Short Version..................... " + QString(Core::shortVersion);
-    diagnosis << "- CamiTK SO NAME........................... " + QString(Core::soVersion);
-    diagnosis << "- Operating System......................... " + stringOS;
-    diagnosis << "- Build type............................... " + compileType;
-    diagnosis << "- QT Version............................... " + QString(QT_VERSION_STR);
-    diagnosis << "- VTK Version.............................. " + QString(vtkVersion::GetVTKVersion());
-    diagnosis << "- Global Installation Directory [G]........ " + globalDir;
-    diagnosis << "- Local Installation Directory [L]......... " + userDir;
-    diagnosis << "- Current Working Directory [W]............ " + currentWorkingDir;
-    diagnosis << "- Test Data Directory...................... " + Core::getTestDataDir();
-    diagnosis << "- Component Extension Directories.......... " + Core::getComponentDirectories().join("\n                                            ");
-    diagnosis << "- Action Extension Directories............. " + Core::getActionDirectories().join("\n                                            ");
-    diagnosis << "- Viewer Extension Directories............. " + Core::getViewerDirectories().join("\n                                            ");
+    diagnosis << "- CamiTK version............................... " + QString(Core::version);
+    diagnosis << "- CamiTK Short Version......................... " + QString(Core::shortVersion);
+    diagnosis << "- CamiTK SO NAME............................... " + QString(Core::soVersion);
+    diagnosis << "- Operating System............................. " + stringOS;
+    diagnosis << "- Build type................................... " + compileType;
+    diagnosis << "- QT Version................................... " + QString(QT_VERSION_STR);
+    diagnosis << "- VTK Version.................................. " + QString(vtkVersion::GetVTKVersion());
+    diagnosis << "- Global Installation Directory [G]............ " + globalDir;
+    diagnosis << "- Local Installation Directory [L]............. " + userDir;
+    diagnosis << "- Current Working Directory [W]................ " + currentWorkingDir;
+    diagnosis << "- Test Data Directory.......................... " + Core::getTestDataDir();
+    diagnosis << "- Component Extension Directories.............. " + Core::getComponentDirectories().join("\n                                                ");
+    diagnosis << "- Action Extension Directories................. " + Core::getActionDirectories().join("\n                                                ");
+    diagnosis << "- Viewer Extension Directories................. " + Core::getViewerDirectories().join("\n                                                ");
 
     return diagnosis.join("\n");
 }
@@ -153,7 +153,7 @@ const QString Core::getConfig() {
     foreach (ComponentExtension* ce, allCE) {
         installationDirectory = ExtensionManager::getInstallationString(ce->getLocation(), globalDir, userDir, currentWorkingDir);
 
-        components << "  - " + installationDirectory + " " + ce->getName().leftJustified(35, '.')  + " " + ce->getFileExtensions().join(", "); // to get more information, use ce->getDescription();
+        components << "  - " + installationDirectory + " " + ce->getName().leftJustified(39, '.')  + " " + ce->getFileExtensions().join(", "); // to get more information, use ce->getDescription();
         extensionCount++;
         extensionUnitCount += ce->getFileExtensions().size();
         if (installationDirectory == "[G]") {
@@ -175,7 +175,7 @@ const QString Core::getConfig() {
     foreach (ComponentExtension* ce, allDCE) {
         installationDirectory = ExtensionManager::getInstallationString(ce->getLocation(), globalDir, userDir, currentWorkingDir);
 
-        components << "  - " + installationDirectory + " " + ce->getName().leftJustified(35, '.') + " directory";
+        components << "  - " + installationDirectory + " " + ce->getName().leftJustified(39, '.') + " directory";
         extensionCount++;
         extensionUnitCount += ce->getFileExtensions().size();
         if (installationDirectory == "[G]") {
@@ -192,8 +192,8 @@ const QString Core::getConfig() {
         }
     }
 
-    diagnosis << "- Number of Component Extensions........... " + QString::number(extensionCount) + " (locations: " + QString::number(globalCount) + " global, " + QString::number(localCount) + " local, " + QString::number(workingDirCount) + " in working directory, " + QString::number(userCount) + " manually installed by user)";
-    diagnosis << "- Number of File Extensions Supported...... " + QString::number(extensionUnitCount);
+    diagnosis << "- Number of Component Extensions............... " + QString::number(extensionCount) + " (locations: " + QString::number(globalCount) + " global, " + QString::number(localCount) + " local, " + QString::number(workingDirCount) + " in working directory, " + QString::number(userCount) + " manually installed by user)";
+    diagnosis << "- Number of File Extensions Supported.......... " + QString::number(extensionUnitCount);
 
     //-- action extensions
     extensionCount = extensionUnitCount = globalCount = localCount = workingDirCount = userCount = 0;
@@ -209,7 +209,7 @@ const QString Core::getConfig() {
 
         installationDirectory = ExtensionManager::getInstallationString(ae->getLocation(), globalDir, userDir, currentWorkingDir);
 
-        actions << "  - " +  installationDirectory + " " + ae->getName().leftJustified(35, '.') + " " + QString::number(ae->getActions().size()) + " actions"; // + ": " + actionNames.join(", ");
+        actions << "  - " +  installationDirectory + " " + ae->getName().leftJustified(39, '.') + " " + QString::number(ae->getActions().size()) + " actions"; // + ": " + actionNames.join(", ");
         extensionCount++;
         extensionUnitCount += ae->getActions().size();
         if (installationDirectory == "[G]") {
@@ -226,8 +226,8 @@ const QString Core::getConfig() {
         }
     }
 
-    diagnosis << "- Number of Action Extensions.............. " + QString::number(extensionCount) + " (locations: " + QString::number(globalCount) + " global, " + QString::number(localCount) + " local, " + QString::number(workingDirCount) + " in working directory, " + QString::number(userCount) + " manually installed by user)";
-    diagnosis << "- Number of Actions........................ " + QString::number(extensionUnitCount);
+    diagnosis << "- Number of Action Extensions.................. " + QString::number(extensionCount) + " (locations: " + QString::number(globalCount) + " global, " + QString::number(localCount) + " local, " + QString::number(workingDirCount) + " in working directory, " + QString::number(userCount) + " manually installed by user)";
+    diagnosis << "- Number of Actions............................ " + QString::number(extensionUnitCount);
 
     //-- viewer extensions
     extensionCount = extensionUnitCount = globalCount = localCount = workingDirCount = userCount = 0;
@@ -243,7 +243,7 @@ const QString Core::getConfig() {
 
         installationDirectory = ExtensionManager::getInstallationString(ve->getLocation(), globalDir, userDir, currentWorkingDir);
 
-        viewers << "  - " +  installationDirectory + " " + ve->getName().leftJustified(35, '.') + " " + QString::number(ve->getViewers().size()) + " viewers"; // + ": " + viewerNames.join(", ");
+        viewers << "  - " +  installationDirectory + " " + ve->getName().leftJustified(39, '.') + " " + QString::number(ve->getViewers().size()) + " viewers"; // + ": " + viewerNames.join(", ");
         extensionCount++;
         extensionUnitCount += ve->getViewers().size();
         if (installationDirectory == "[G]") {
@@ -260,17 +260,17 @@ const QString Core::getConfig() {
         }
     }
 
-    diagnosis << "- Number of Viewer Extensions.............. " + QString::number(extensionCount) + " (locations: " + QString::number(globalCount) + " global, " + QString::number(localCount) + " local, " + QString::number(workingDirCount) + " in working directory, " + QString::number(userCount) + " manually installed by user)";
-    diagnosis << "- Number of Viewers........................ " + QString::number(extensionUnitCount);
+    diagnosis << "- Number of Viewer Extensions.................. " + QString::number(extensionCount) + " (locations: " + QString::number(globalCount) + " global, " + QString::number(localCount) + " local, " + QString::number(workingDirCount) + " in working directory, " + QString::number(userCount) + " manually installed by user)";
+    diagnosis << "- Number of Viewers............................ " + QString::number(extensionUnitCount);
 
     //-- details of the extensions
-    diagnosis << "- Registered components:";
+    diagnosis << "- Registered component extensions:";
     diagnosis += components;
 
-    diagnosis << "- Registered actions:";
+    diagnosis << "- Registered action extensions:";
     diagnosis += actions;
 
-    diagnosis << "- Registered viewers:";
+    diagnosis << "- Registered viewer extensions:";
     diagnosis += viewers;
 
     return diagnosis.join("\n");
@@ -312,13 +312,17 @@ const QStringList Core::getInstallDirectories(QString suffix, bool exitOnError)
 // ------------- getExtensionDirectories (static) -----------------
 const QStringList Core::getExtensionDirectories(QString extensionType) {
     QStringList installDirectories = getInstallDirectories(QString(Core::libDir) + "/" + QString(Core::shortVersion) + "/" + extensionType);
-    QSet<QString> multiarchInstalledDirectories(installDirectories.begin(), installDirectories.end());
+    installDirectories.removeDuplicates();
+
+    //QStringList multiarchInstalledDirectories(installDirectories.begin(), installDirectories.end());
     if (QString(Core::libDir) != "lib") {
         // multiarch installation in "lib/xx" requires checking non-multiarch aware current repositories that uses default "lib/"
-        QStringList libInstallDirectories = getInstallDirectories("lib/" + QString(Core::shortVersion) + "/" + extensionType, false);
-        multiarchInstalledDirectories += QSet<QString>(libInstallDirectories.begin(), libInstallDirectories.end());
+        QStringList supplementalInstallDirectories = getInstallDirectories("lib/" + QString(Core::shortVersion) + "/" + extensionType, false);
+        supplementalInstallDirectories.removeDuplicates();
+        installDirectories += supplementalInstallDirectories;
     }
-    return multiarchInstalledDirectories.values();
+
+    return installDirectories;
 }
 
 // ------------- getActionDirectories (static) -----------------
