@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -28,6 +28,7 @@
 
 // -- Core stuff
 #include "CamiTKAPI.h"
+#include "InterfacePersistence.h"
 #include <Application.h>
 #include <Component.h>
 
@@ -205,7 +206,7 @@ class HistoryItem;
  * @see ChangeColor For a simple example of an action with no widget (but with a GUI)
 */
 
-class CAMITK_API Action : public QObject {
+class CAMITK_API Action : public QObject, public InterfacePersistence {
     Q_OBJECT
 
 public:
@@ -236,6 +237,8 @@ public:
     ///@return the QString equivalent of the given status
     static QString getStatusAsString(ApplyStatus);
 
+
+
 public slots:
     /**
      * This method triggers the action.
@@ -441,6 +444,18 @@ public:
     void applyTargetPosition(Component* input, Component* target, Application::TargetPositionningPolicy policy);
     /// @}
 
+    /**
+     * * @name InterfacePersistence
+     * Customized InterfacePersistence methods to support geometry data (e.g. color)
+     */
+    ///@{
+    /// Convert all data from the object to a QVariant (usually a QVariantMap)
+    virtual QVariant toVariant() const override;
+
+    /// Load data from a QVariant to initialize the current object
+    virtual void fromVariant(const QVariant&) override;
+    ///@}
+
 protected:
     /** @name Generic action attributes setters
      *  These methods can not be redefined in subclasses but have to be used to ensure name/description uniqueness
