@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -35,6 +35,7 @@
 #include "Property.h"
 #include "PropertyObject.h"
 #include "Log.h"
+#include "PersistenceManager.h"
 
 // -- QT stuff
 #include <QSettings>
@@ -259,7 +260,10 @@ void Application::setMainWindow(MainWindow* mw) {
     // by default redirect to console
     mainWindow->redirectToConsole(true);
 
-    // Set the locale to C for using dot as decimal point dispite locale
+    // apply properties that modify the main window (e.g. stylesheet for splitter/separator)
+    applyMainWindowPropertyValues();
+
+    // Set the locale to C for using dot as decimal point despite locale
     // Set utf8 for output to enforce using utf8 strings.
     //
     // see http://doc.qt.io/qt-5/qcoreapplication.html#locale-settings
@@ -492,12 +496,8 @@ Component* Application::open(const QString& fileName) {
             // open using transformed path so that anything looking like C:\\Dir1\\Dir2\\foo.zzz is unified to a C:/Dir1/Dir2/foo.zz
             comp = componentExtension->open(QFileInfo(fileName).absoluteFilePath());
 
-            // -- notify the application
-            if (comp == nullptr) {
-                showStatusBarMessage(tr("Error loading file:") + fileName);
-            }
-            else {
-                // add the document to the recent list
+            if (comp != nullptr) {
+                // if a component is created, add the document to the recent list
                 addRecentDocument(fileName);
                 showStatusBarMessage(tr(QString("File " + fileName + " successfully loaded").toStdString().c_str()));
 
@@ -625,6 +625,24 @@ Component* Application::openDirectory(const QString& dirName, const QString& plu
     return comp;
 }
 
+// -------------------- loadWorkspace --------------------
+bool Application::loadWorkspace(const QString& filepath) {
+    if (PersistenceManager::loadWorkspace(filepath)) {
+        // Update MainWindow settings
+        MainWindow* window = getMainWindow();
+        if (window) {
+            window->initSettings();
+        }
+        // add the document to the recent list
+        addRecentDocument(filepath);
+        showStatusBarMessage(tr("Workspace %1 successfully loaded").arg(filepath));
+        return true;
+    }
+    else {
+        return false;
+    }
+}
+
 // -------------------------- close ------------------------------
 bool Application::close(Component* comp) {
     int keyPressed = QMessageBox::Discard;
@@ -668,6 +686,7 @@ bool Application::save(Component* component) {
 
     // no name -> save as
     if (component->getFileName().isEmpty()) {
+        getAction("Save As")->setInputComponent(component);
         return (getAction("Save As")->apply() == Action::SUCCESS);
     }
 
@@ -714,6 +733,7 @@ bool Application::save(Component* component) {
             // update the last used dir
             setLastUsedDirectory(QFileInfo(component->getFileName()).absoluteDir());
             showStatusBarMessage(tr("%1 successfully saved...").arg(component->getName()));
+            component->setModified(false);
 
             QApplication::restoreOverrideCursor();
             return true;
@@ -725,6 +745,24 @@ bool Application::save(Component* component) {
     }
 }
 
+bool Application::saveWorkspace(const QString& filepath) {
+    // Check whether all components are saved
+    QStringList unsavedComps;
+    for (auto* c : Application::getTopLevelComponents()) {
+        if (c->getModified()) {
+            unsavedComps.push_back(c->getName());
+        }
+    }
+    if (!unsavedComps.isEmpty()) {
+        CAMITK_WARNING_ALT("Some components are not saved, saving the workspace will not save them !");
+    }
+    // Make sure the mainwindow has saved its settings
+    MainWindow* window = getMainWindow();
+    if (window) {
+        window->saveSettings();
+    }
+    return PersistenceManager::saveWorkspace(filepath);
+}
 
 // -------------------- getActionMap --------------------
 QMap<QString, Action*>& Application::getActionMap() {
@@ -1526,6 +1564,10 @@ void Application::createProperties() {
     property = new Property("Display Time Stamp Information to Log Message", Log::getLogger()->getTimeStampInformation(), "If true display the time stamp for every log message in the \"yyyy-MM-dd HH:mm:ss.zzz\" format.", "");
     propertyObject->addProperty(property);
 
+    // -- Window Separator Size
+    property = new Property("Window Separator Size", 2, "The size in pixels of the separator between dock widgets and the central widget. Change the value if you prefer a larger splitter. If value is 1, no highlight is visible.", "pixels");
+    property->setAttribute("minimum", 1);
+    propertyObject->addProperty(property);
 }
 
 // ---------------------- getPropertyObject ------------------
@@ -1568,7 +1610,24 @@ void Application::applyPropertyValues() {
     Log::getLogger()->setTimeStampInformation(propertyObject->property("Display Time Stamp Information to Log Message").toBool());
     Log::getLogger()->setLogToStandardOutput(propertyObject->property("Log to Standard Output").toBool());
     Log::getLogger()->setLogToFile(propertyObject->property("Log to File").toBool());
+
+    applyMainWindowPropertyValues();
 }
 
+
+// ---------------------- applyMainWindowPropertyValues ------------------
+void Application::applyMainWindowPropertyValues() {
+    // increase the size and highlight the separator between dock widgets and central widget
+    // by setting the stylesheet
+    if (mainWindow != nullptr) {
+        mainWindow->setStyleSheet(QString("QMainWindow::separator { \
+          width: %1px; \
+          height: %1px; \
+        } \
+        QMainWindow::separator:hover { \
+          background: palette(highlight); \
+        }").arg(propertyObject->property("Window Separator Size").toInt()));
+    }
+}
 }
 
