@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -194,6 +194,10 @@ public:
      */
     static Component* openDirectory(const QString& dirName, const QString& pluginName);
 
+    /** load a camitk file and its content into the application
+     */
+    static bool loadWorkspace(const QString& filepath);
+
     /** Close a Component: if it has been changed, ask the user for more information, then if everything is ok, delete it.
     *    @param component the Component to close.
     *    @return true if the closing was made, false if the user cancelled the operation or a saving problem occurs
@@ -207,6 +211,12 @@ public:
      */
     static bool save(Component* component);
 
+    /** save the current workspace to a .camitk file.
+     *
+     *  This method uses PersistenceManager to save the workspace
+     */
+    static bool saveWorkspace(const QString& filepath);
+
     /** get the current application wide list of instantiated top-level Components.
       * This is the public method (return a const, the top-level component list is private
       * and cannot be modified externally).
@@ -417,6 +427,7 @@ public:
     /// @{
     /// class Component is a friend class: only the class Component can access to the private members addComponent(..) and removeComponent(..)
     friend class Component;
+    friend class PersistenceManager;
     /// @}
 
 private slots:
@@ -521,6 +532,10 @@ private:
 
     /// Apply all the property values to update the model (e.g., use the logLevel to modify the actual log level of the application logger)
     static void applyPropertyValues();
+
+    /// Apply main window specific settings once it is set or instantiated (e.g. stylesheet)
+    static void applyMainWindowPropertyValues();
+
     ///@}
 
     ///@name Actions pipeline history
