@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -409,6 +409,7 @@ void MainWindow::show() {
     if (toggleAction) {
         toggleAction->getQAction()->setChecked(consoleWindow->isVisible());
     }
+
 }
 
 // ------------- aboutToShow -----------------
@@ -436,7 +437,7 @@ void MainWindow::initSettings() {
 
     // get central viewer
     QString centralViewerName = settings.value("centralViewer", "").toString();
-    // if no specific name is found, just do nothing will use the one alread set in the central viewer by default
+    // if no specific name is found, just do nothing will use the one already set in the central viewer by default
     if (centralViewerName != "" && Application::getViewer(centralViewerName) != nullptr) {
         setCentralViewer(Application::getViewer(centralViewerName));
     }
@@ -444,18 +445,24 @@ void MainWindow::initSettings() {
     settings.endGroup();
 }
 
+// ------------- saveSettings -----------------
+void MainWindow::saveSettings() {
+    QSettings& settings = Application::getSettings();
+    settings.beginGroup(Application::getName() + ".MainWindow");
+    settings.setValue("geometry", geometry());
+    settings.setValue("windowState", saveState());
+    settings.endGroup();
+}
+
 // ------------- closeEvent -----------------
 void MainWindow::closeEvent(QCloseEvent* event) {
     statusBar()->showMessage(tr("Exiting application..."));
 
+    // Reset the stylesheet that was set in Application (fixes Qt crash on exit)
+    setStyleSheet("");
+
     if (Application::getAction("Close All")->apply() == Action::SUCCESS) {
-
-        QSettings& settings = Application::getSettings();
-        settings.beginGroup(Application::getName() + ".MainWindow");
-        settings.setValue("geometry", geometry());
-        settings.setValue("windowState", saveState());
-        settings.endGroup();
-
+        saveSettings();
         event->accept();
     }
     else {
