@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -29,8 +29,10 @@
 #include "Property.h"
 #include "Action.h"
 #include "Frame.h"
+#include "PersistenceManager.h"
 #include "Log.h"
 
+
 // -- QT stuff
 #include <QEvent>
 #include <QMetaObject>
@@ -446,6 +448,59 @@ void Component::setFileName(const QString& fName) {
 
 
 
+// -----------------------------------------------------------------------
+//
+//                        InterfacePersistence methods
+//
+// -----------------------------------------------------------------------
+
+// -------------------- toVariant --------------------
+
+QVariant Component::toVariant() const {
+    QString transformMatrix = "";
+    auto transform = getTransform();
+    if (transform) {
+        auto matrix = transform->GetMatrix();
+        for (int i = 0; i < 4; ++i) {
+            for (int j = 0; j < 4; ++j) {
+                transformMatrix += QString::number(matrix->GetElement(i, j)) + " ";
+            }
+        }
+
+    }
+    QString parentFrameName = getParentFrame() ? getParentFrame()->getFrameName() : "";
+    return QVariantMap({{"filename", getFileName()}, {"properties", PersistenceManager::fromProperties(getPropertyObject())},
+        {"parentFrame", parentFrameName}, {"frameName", getFrameName()},
+        {"frameTransform", transformMatrix}
+    });
+}
+
+// -------------------- fromVariant --------------------
+void Component::fromVariant(const QVariant& newValues) {
+    // TODO Manage UUID, transforms...
+    QVariantMap newValuesMap = newValues.toMap();
+    if (newValuesMap.contains("properties")) {
+        PersistenceManager::loadProperties(this, newValuesMap.value("properties"));
+    }
+    if (newValuesMap.contains("frameName")) {
+        setFrameName(newValuesMap.value("frameName").toString());
+    }
+    if (newValuesMap.contains("frameTransform")) {
+        QStringList elements = newValuesMap.value("frameTransform").toString().split(" ");
+        if (elements.size() >= 16) {
+            auto matrix = vtkSmartPointer<vtkMatrix4x4>::New();
+            for (int i = 0; i < 4; ++i) {
+                for (int j = 0; j < 4; ++j) {
+                    matrix->SetElement(i, j, elements[i * 4 + j].toDouble());
+                }
+            }
+            this->getTransform()->SetMatrix(matrix);
+        }
+
+    }
+}
+
+
 
 // -----------------------------------------------------------------------
 //
@@ -620,7 +675,7 @@ const InterfaceGeometry::RenderingModes Component::getRenderingModes() const {
 }
 
 // -------------------- getActorColor --------------------
-void Component::getActorColor(InterfaceGeometry::RenderingModes m, double d[4])  {
+void Component::getActorColor(InterfaceGeometry::RenderingModes m, double d[4]) const {
     if (myGeometry) {
         // get the color of myGeometry, is exists, and finished
         myGeometry->getActorColor(m, d);
