@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -362,6 +362,20 @@ public:
      * @}
      */
 
+
+    /**
+     * * @name InterfacePersistence
+     * Customized InterfacePersistence methods to support geometry data (e.g. color)
+     */
+    ///@{
+    /// Convert all data from the object to a QVariant (usually a QVariantMap)
+    virtual QVariant toVariant() const override;
+
+    /// Load data from a QVariant to initialize the current object
+    virtual void fromVariant(const QVariant&) override;
+    ///@}
+
+
 protected:
 
     /// build the instance of Geometry from the given vtkPointSet
