@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -371,19 +371,8 @@ void ObjectControllerPrivate::addDynamicProperties(QObject* edited) {
 
         // check if the edited object use a list of camitk::Property to
         // add more information about the dynamic property
-        Property* camitkProp = nullptr;
-        bool getPropertyExist = QMetaObject::invokeMethod(edited, "getProperty", Qt::DirectConnection,
-                                Q_RETURN_ARG(Property*, camitkProp),
-                                Q_ARG(QString, pName));
-
-        // try harder (in case the edited object was not declared in the camitk namespace)
-        if (!getPropertyExist) {
-            getPropertyExist = QMetaObject::invokeMethod(edited, "getProperty", Qt::DirectConnection,
-                               Q_RETURN_ARG(camitk::Property*, camitkProp),
-                               Q_ARG(QString, pName));
-        }
-
-        if (!getPropertyExist || camitkProp == nullptr) {
+        Property* camitkProp = Property::getProperty(edited, pName);
+        if (camitkProp == nullptr) {
             // the old way, build a simple dynamic variant property
             subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ true, false, false, true);
         }
