@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -388,6 +388,18 @@ public:
      */
     QString getGroupName() const;
 
+    /// @brief get the camitk::Property decoration of a named property of the given QObject or nullptr if object does not have any camitk::Property
+    ///
+    /// \note
+    /// If object is an instance of a class that declares a Q_INVOKABLE getProperty(QString) method, it means that a Qt Property "decoration"
+    /// was stored. In this case, this method returns the result of getProperty(name) (i.e., it is expected that the result won't b nullptr
+    /// if the named property is found.
+    ///
+    /// @param object The QObject to check
+    /// @param name The property name to look for
+    /// @return the pointer to the camitk::Property corresponding to the CamiTK Property of the named property
+    static Property* getProperty(QObject* object, QString name);
+
 private:
     /// name of the property
     QString name;
