@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -165,7 +165,7 @@ public:
     QWidget* getWidget() override;
 
     /// get the  InteractiveViewer propertyObject (only non-null for GEOMETRY_VIEWER)
-    QObject* getPropertyObject() override;
+    PropertyObject* getPropertyObject() override;
 
     /// get the explorer menu
     QMenu* getMenu() override;
