@@ -47,6 +47,8 @@
 QT_BEGIN_NAMESPACE
 #endif
 
+class QRegularExpression;
+
 class QtSpinBoxFactoryPrivate;
 
 /**
@@ -69,7 +71,11 @@ protected:
 private:
     QtSpinBoxFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtSpinBoxFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtSpinBoxFactory)
+#else
     Q_DISABLE_COPY(QtSpinBoxFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotRangeChanged(QtProperty*, int, int))
     Q_PRIVATE_SLOT(d_func(), void slotSingleStepChanged(QtProperty*, int))
@@ -92,7 +98,11 @@ protected:
 private:
     QtSliderFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtSliderFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtSliderFactory)
+#else
     Q_DISABLE_COPY(QtSliderFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotRangeChanged(QtProperty*, int, int))
     Q_PRIVATE_SLOT(d_func(), void slotSingleStepChanged(QtProperty*, int))
@@ -115,7 +125,11 @@ protected:
 private:
     QtScrollBarFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtScrollBarFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtScrollBarFactory)
+#else
     Q_DISABLE_COPY(QtScrollBarFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotRangeChanged(QtProperty*, int, int))
     Q_PRIVATE_SLOT(d_func(), void slotSingleStepChanged(QtProperty*, int))
@@ -138,7 +152,11 @@ protected:
 private:
     QtCheckBoxFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtCheckBoxFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtCheckBoxFactory)
+#else
     Q_DISABLE_COPY(QtCheckBoxFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, bool))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(bool))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
@@ -159,7 +177,11 @@ protected:
 private:
     QtDoubleSpinBoxFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtDoubleSpinBoxFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtDoubleSpinBoxFactory)
+#else
     Q_DISABLE_COPY(QtDoubleSpinBoxFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, double))
     Q_PRIVATE_SLOT(d_func(), void slotRangeChanged(QtProperty*, double, double))
     Q_PRIVATE_SLOT(d_func(), void slotSingleStepChanged(QtProperty*, double))
@@ -183,9 +205,13 @@ protected:
 private:
     QtLineEditFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtLineEditFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtLineEditFactory)
+#else
     Q_DISABLE_COPY(QtLineEditFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QString&))
-    Q_PRIVATE_SLOT(d_func(), void slotRegExpChanged(QtProperty*, const QRegExp&))
+    Q_PRIVATE_SLOT(d_func(), void slotRegExpChanged(QtProperty*, const QRegularExpression&))
     Q_PRIVATE_SLOT(d_func(), void slotEchoModeChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(const QString&))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
@@ -206,7 +232,11 @@ protected:
 private:
     QtDateEditFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtDateEditFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtDateEditFactory)
+#else
     Q_DISABLE_COPY(QtDateEditFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QDate&))
     Q_PRIVATE_SLOT(d_func(), void slotRangeChanged(QtProperty*,
                    const QDate&, const QDate&))
@@ -229,7 +259,11 @@ protected:
 private:
     QtTimeEditFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtTimeEditFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtTimeEditFactory)
+#else
     Q_DISABLE_COPY(QtTimeEditFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QTime&))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(const QTime&))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
@@ -250,7 +284,11 @@ protected:
 private:
     QtDateTimeEditFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtDateTimeEditFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtDateTimeEditFactory)
+#else
     Q_DISABLE_COPY(QtDateTimeEditFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QDateTime&))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(const QDateTime&))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
@@ -271,7 +309,11 @@ protected:
 private:
     QtKeySequenceEditorFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtKeySequenceEditorFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtKeySequenceEditorFactory)
+#else
     Q_DISABLE_COPY(QtKeySequenceEditorFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QKeySequence&))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(const QKeySequence&))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
@@ -292,7 +334,11 @@ protected:
 private:
     QtCharEditorFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtCharEditorFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtCharEditorFactory)
+#else
     Q_DISABLE_COPY(QtCharEditorFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QChar&))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(const QChar&))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
@@ -313,7 +359,11 @@ protected:
 private:
     QtEnumEditorFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtEnumEditorFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtEnumEditorFactory)
+#else
     Q_DISABLE_COPY(QtEnumEditorFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotEnumNamesChanged(QtProperty*,
                    const QStringList&))
@@ -338,7 +388,11 @@ protected:
 private:
     QtCursorEditorFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtCursorEditorFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtCursorEditorFactory)
+#else
     Q_DISABLE_COPY(QtCursorEditorFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QCursor&))
     Q_PRIVATE_SLOT(d_func(), void slotEnumChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
@@ -359,7 +413,11 @@ protected:
 private:
     QtColorEditorFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtColorEditorFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtColorEditorFactory)
+#else
     Q_DISABLE_COPY(QtColorEditorFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QColor&))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(const QColor&))
@@ -380,7 +438,11 @@ protected:
 private:
     QtFontEditorFactoryPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtFontEditorFactory)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtFontEditorFactory)
+#else
     Q_DISABLE_COPY(QtFontEditorFactory)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotPropertyChanged(QtProperty*, const QFont&))
     Q_PRIVATE_SLOT(d_func(), void slotEditorDestroyed(QObject*))
     Q_PRIVATE_SLOT(d_func(), void slotSetValue(const QFont&))
