@@ -422,7 +422,7 @@ void QtProperty::insertSubProperty(QtProperty* property,
     }
 
     // traverse all children of item. if this item is a child of item then cannot add.
-    QList<QtProperty*> pendingList = property->subProperties();
+    auto pendingList = property->subProperties();
     QMap<QtProperty*, bool> visited;
     while (!pendingList.isEmpty()) {
         QtProperty* i = pendingList.first();
@@ -472,7 +472,7 @@ void QtProperty::removeSubProperty(QtProperty* property) {
 
     d_ptr->m_manager->d_ptr->propertyRemoved(property, this);
 
-    QList<QtProperty*> pendingList = subProperties();
+    auto pendingList = subProperties();
     int pos = 0;
     while (pos < pendingList.count()) {
         if (pendingList.at(pos) == property) {
@@ -678,7 +678,7 @@ QSet<QtProperty*> QtAbstractPropertyManager::properties() const {
     \sa QtProperty::hasValue()
 */
 bool QtAbstractPropertyManager::hasValue(const QtProperty* property) const {
-    Q_UNUSED(property)
+    Q_UNUSED(property);
     return true;
 }
 
@@ -692,7 +692,7 @@ bool QtAbstractPropertyManager::hasValue(const QtProperty* property) const {
     \sa QtProperty::valueIcon()
 */
 QIcon QtAbstractPropertyManager::valueIcon(const QtProperty* property) const {
-    Q_UNUSED(property)
+    Q_UNUSED(property);
     return QIcon();
 }
 
@@ -706,7 +706,7 @@ QIcon QtAbstractPropertyManager::valueIcon(const QtProperty* property) const {
     \sa QtProperty::valueText()
 */
 QString QtAbstractPropertyManager::valueText(const QtProperty* property) const {
-    Q_UNUSED(property)
+    Q_UNUSED(property);
     return QString();
 }
 
@@ -720,7 +720,7 @@ QString QtAbstractPropertyManager::valueText(const QtProperty* property) const {
     \sa QtProperty::valueText()
 */
 QString QtAbstractPropertyManager::displayText(const QtProperty* property) const {
-    Q_UNUSED(property)
+    Q_UNUSED(property);
     return QString();
 }
 
@@ -733,7 +733,7 @@ QString QtAbstractPropertyManager::displayText(const QtProperty* property) const
     \sa QtProperty::valueText()
 */
 EchoMode QtAbstractPropertyManager::echoMode(const QtProperty* property) const {
-    Q_UNUSED(property)
+    Q_UNUSED(property);
     return QLineEdit::Normal;
 }
 
@@ -776,9 +776,9 @@ QtProperty* QtAbstractPropertyManager::createProperty() {
 
     The purpose is to let the manager know that the \a property has
     been created so that it can provide additional attributes for the
-    new property, e.g. QtIntPropertyManager adds \l
-    {QtIntPropertyManager::value()}{value}, \l
-    {QtIntPropertyManager::minimum()}{minimum} and \l
+    new property, e.g. QtIntPropertyManager adds <br/>
+    {QtIntPropertyManager::value()}{value},<br/>
+    {QtIntPropertyManager::minimum()}{minimum} and <br/>
     {QtIntPropertyManager::maximum()}{maximum} attributes. Since each manager
     subclass adds type specific attributes, this function is pure
     virtual and must be reimplemented when deriving from the
@@ -797,7 +797,7 @@ QtProperty* QtAbstractPropertyManager::createProperty() {
     \sa clear(),  propertyDestroyed()
 */
 void QtAbstractPropertyManager::uninitializeProperty(QtProperty* property) {
-    Q_UNUSED(property)
+    Q_UNUSED(property);
 }
 
 ////////////////////////////////////
@@ -826,19 +826,19 @@ void QtAbstractPropertyManager::uninitializeProperty(QtProperty* property) {
     QtAbstractEditorFactoryBase. But note that several ready-made
     implementations are available:
 
-    \list
-    \o QtCheckBoxFactory
-    \o QtDateEditFactory
-    \o QtDateTimeEditFactory
-    \o QtDoubleSpinBoxFactory
-    \o QtEnumEditorFactory
-    \o QtLineEditFactory
-    \o QtScrollBarFactory
-    \o QtSliderFactory
-    \o QtSpinBoxFactory
-    \o QtTimeEditFactory
-    \o QtVariantEditorFactory
-    \endlist
+    <ol>
+    <li> QtCheckBoxFactory </li>
+    <li> QtDateEditFactory </li>
+    <li> QtDateTimeEditFactory </li>
+    <li> QtDoubleSpinBoxFactory </li>
+    <li> QtEnumEditorFactory </li>
+    <li> QtLineEditFactory </li>
+    <li> QtScrollBarFactory </li>
+    <li> QtSliderFactory </li>
+    <li> QtSpinBoxFactory </li>
+    <li> QtTimeEditFactory </li>
+    <li> QtVariantEditorFactory </li>
+    </ol>
 
     \sa QtAbstractPropertyManager, QtAbstractPropertyBrowser
 */
@@ -927,19 +927,19 @@ void QtAbstractPropertyManager::uninitializeProperty(QtProperty* property) {
     Several ready-made implementations of the QtAbstractEditorFactory class
     are available:
 
-    \list
-    \o QtCheckBoxFactory
-    \o QtDateEditFactory
-    \o QtDateTimeEditFactory
-    \o QtDoubleSpinBoxFactory
-    \o QtEnumEditorFactory
-    \o QtLineEditFactory
-    \o QtScrollBarFactory
-    \o QtSliderFactory
-    \o QtSpinBoxFactory
-    \o QtTimeEditFactory
-    \o QtVariantEditorFactory
-    \endlist
+    <ol>
+    <li> QtCheckBoxFactory </li>
+    <li> QtDateEditFactory </li>
+    <li> QtDateTimeEditFactory </li>
+    <li> QtDoubleSpinBoxFactory </li>
+    <li> QtEnumEditorFactory </li>
+    <li> QtLineEditFactory </li>
+    <li> QtScrollBarFactory </li>
+    <li> QtSliderFactory </li>
+    <li> QtSpinBoxFactory </li>
+    <li> QtTimeEditFactory </li>
+    <li> QtVariantEditorFactory </li>
+    </ol>
 
     When deriving from the QtAbstractEditorFactory class, several pure virtual
     functions must be implemented: the connectPropertyManager() function is
@@ -1066,7 +1066,7 @@ void QtAbstractPropertyManager::uninitializeProperty(QtProperty* property) {
     \fn virtual void QtAbstractEditorFactory::managerDestroyed(QObject *manager)
 
     \internal
-    \reimp
+
 */
 
 ////////////////////////////////////
@@ -1223,8 +1223,7 @@ public:
     QtBrowserItem* m_currentItem{nullptr};
 };
 
-QtAbstractPropertyBrowserPrivate::QtAbstractPropertyBrowserPrivate()
-{
+QtAbstractPropertyBrowserPrivate::QtAbstractPropertyBrowserPrivate() {
 }
 
 void QtAbstractPropertyBrowserPrivate::insertSubTree(QtProperty* property,
@@ -1256,7 +1255,7 @@ void QtAbstractPropertyBrowserPrivate::insertSubTree(QtProperty* property,
     m_managerToProperties[manager].append(property);
     m_propertyToParents[property].append(parentProperty);
 
-    QList<QtProperty*> subList = property->subProperties();
+    const auto subList = property->subProperties();
     QListIterator<QtProperty*> itSub(subList);
     while (itSub.hasNext()) {
         QtProperty* subProperty = itSub.next();
@@ -1296,7 +1295,7 @@ void QtAbstractPropertyBrowserPrivate::removeSubTree(QtProperty* property,
         m_managerToProperties.remove(manager);
     }
 
-    QList<QtProperty*> subList = property->subProperties();
+    const auto subList = property->subProperties();
     QListIterator<QtProperty*> itSub(subList);
     while (itSub.hasNext()) {
         QtProperty* subProperty = itSub.next();
@@ -1307,8 +1306,7 @@ void QtAbstractPropertyBrowserPrivate::removeSubTree(QtProperty* property,
 void QtAbstractPropertyBrowserPrivate::createBrowserIndexes(QtProperty* property, QtProperty* parentProperty, QtProperty* afterProperty) {
     QMap<QtBrowserItem*, QtBrowserItem*> parentToAfter;
     if (afterProperty) {
-        QMap<QtProperty*, QList<QtBrowserItem*> >::ConstIterator it =
-            m_propertyToIndexes.find(afterProperty);
+        const auto it = m_propertyToIndexes.find(afterProperty);
         if (it == m_propertyToIndexes.constEnd()) {
             return;
         }
@@ -1324,8 +1322,7 @@ void QtAbstractPropertyBrowserPrivate::createBrowserIndexes(QtProperty* property
         }
     }
     else if (parentProperty) {
-        QMap<QtProperty*, QList<QtBrowserItem*> >::ConstIterator it =
-            m_propertyToIndexes.find(parentProperty);
+        const auto it = m_propertyToIndexes.find(parentProperty);
         if (it == m_propertyToIndexes.constEnd()) {
             return;
         }
@@ -1361,7 +1358,7 @@ QtBrowserItem* QtAbstractPropertyBrowserPrivate::createBrowserIndex(QtProperty*
 
     q_ptr->itemInserted(newIndex, afterIndex);
 
-    QList<QtProperty*> subItems = property->subProperties();
+    const auto subItems = property->subProperties();
     QListIterator<QtProperty*> itChild(subItems);
     QtBrowserItem* afterChild = nullptr;
     while (itChild.hasNext()) {
@@ -1373,8 +1370,7 @@ QtBrowserItem* QtAbstractPropertyBrowserPrivate::createBrowserIndex(QtProperty*
 
 void QtAbstractPropertyBrowserPrivate::removeBrowserIndexes(QtProperty* property, QtProperty* parentProperty) {
     QList<QtBrowserItem*> toRemove;
-    QMap<QtProperty*, QList<QtBrowserItem*> >::ConstIterator it =
-        m_propertyToIndexes.find(property);
+    const auto it = m_propertyToIndexes.find(property);
     if (it == m_propertyToIndexes.constEnd()) {
         return;
     }
@@ -1397,7 +1393,7 @@ void QtAbstractPropertyBrowserPrivate::removeBrowserIndexes(QtProperty* property
 }
 
 void QtAbstractPropertyBrowserPrivate::removeBrowserIndex(QtBrowserItem* index) {
-    QList<QtBrowserItem*> children = index->children();
+    const auto children = index->children();
     for (int i = children.count(); i > 0; i--) {
         removeBrowserIndex(children.at(i - 1));
     }
@@ -1423,7 +1419,7 @@ void QtAbstractPropertyBrowserPrivate::removeBrowserIndex(QtBrowserItem* index)
 }
 
 void QtAbstractPropertyBrowserPrivate::clearIndex(QtBrowserItem* index) {
-    QList<QtBrowserItem*> children = index->children();
+    const auto children = index->children();
     QListIterator<QtBrowserItem*> itChild(children);
     while (itChild.hasNext()) {
         clearIndex(itChild.next());
@@ -1463,13 +1459,12 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty* prope
         return;
     }
 
-    QMap<QtProperty*, QList<QtBrowserItem*> >::ConstIterator it =
-        m_propertyToIndexes.find(property);
+    const auto it = m_propertyToIndexes.find(property);
     if (it == m_propertyToIndexes.constEnd()) {
         return;
     }
 
-    QList<QtBrowserItem*> indexes = it.value();
+    const auto indexes = it.value();
     QListIterator<QtBrowserItem*> itIndex(indexes);
     while (itIndex.hasNext()) {
         QtBrowserItem* idx = itIndex.next();
@@ -1490,8 +1485,6 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty* prope
     edit or a combobox) holding its value. A property can have zero or
     more subproperties.
 
-    \image qtpropertybrowser.png
-
     The top level properties can be retrieved using the
     properties() function. To traverse each property's
     subproperties, use the QtProperty::subProperties() function. In
@@ -1536,9 +1529,6 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty* prope
     instances can appear several times in an abstract tree
     structure. For example:
 
-    \table 100%
-    \row
-    \o
     \code
         QtProperty *property1, *property2, *property3;
 
@@ -1551,8 +1541,6 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty* prope
         editor->addProperty(property2);
         editor->addProperty(property3);
     \endcode
-    \o  \image qtpropertybrowser-duplicate.png
-    \endtable
 
     The addProperty() function returns a QtBrowserItem that uniquely
     identifies the created item.
@@ -1564,10 +1552,10 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty* prope
     Note that there are two ready-made property browser
     implementations:
 
-    \list
-        \o QtGroupBoxPropertyBrowser
-        \o QtTreePropertyBrowser
-    \endlist
+    <ol>
+        <li>QtGroupBoxPropertyBrowser</li>
+        <li>QtTreePropertyBrowser</li>
+    <ol>
 
     \sa QtAbstractPropertyManager, QtAbstractEditorFactoryBase
 */
@@ -1696,7 +1684,7 @@ QtAbstractPropertyBrowser::QtAbstractPropertyBrowser(QWidget* parent)
     \sa QtAbstractPropertyManager::~QtAbstractPropertyManager()
 */
 QtAbstractPropertyBrowser::~QtAbstractPropertyBrowser() {
-    QList<QtBrowserItem*> indexes = topLevelItems();
+    const auto indexes = topLevelItems();
     QListIterator<QtBrowserItem*> itItem(indexes);
     while (itItem.hasNext()) {
         d_ptr->clearIndex(itItem.next());
@@ -1759,7 +1747,7 @@ QList<QtBrowserItem*> QtAbstractPropertyBrowser::topLevelItems() const {
     \sa removeProperty(), QtAbstractPropertyManager::clear()
 */
 void QtAbstractPropertyBrowser::clear() {
-    QList<QtProperty*> subList = properties();
+    const auto subList = properties();
     QListIterator<QtProperty*> itSub(subList);
     itSub.toBack();
     while (itSub.hasPrevious()) {
@@ -1811,7 +1799,7 @@ QtBrowserItem* QtAbstractPropertyBrowser::insertProperty(QtProperty* property,
     }
 
     // if item is already inserted in this item then cannot add.
-    QList<QtProperty*> pendingList = properties();
+    auto pendingList = properties();
     int pos = 0;
     int newPos = 0;
     //QtProperty *properAfterProperty = 0;
@@ -1852,7 +1840,7 @@ void QtAbstractPropertyBrowser::removeProperty(QtProperty* property) {
         return;
     }
 
-    QList<QtProperty*> pendingList = properties();
+    auto pendingList = properties();
     int pos = 0;
     while (pos < pendingList.count()) {
         if (pendingList.at(pos) == property) {
