@@ -61,6 +61,7 @@ class QDate;
 class QTime;
 class QDateTime;
 class QLocale;
+class QRegularExpression;
 
 /**
  * @ingroup group_sdk_libraries_qtpropertybrowser
@@ -119,7 +120,11 @@ protected:
 private:
     QtIntPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtIntPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtIntPropertyManager)
+#else
     Q_DISABLE_COPY(QtIntPropertyManager)
+#endif
 };
 
 class QtBoolPropertyManagerPrivate;
@@ -147,7 +152,11 @@ protected:
 private:
     QtBoolPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtBoolPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtBoolPropertyManager)
+#else
     Q_DISABLE_COPY(QtBoolPropertyManager)
+#endif
 };
 
 class QtDoublePropertyManagerPrivate;
@@ -186,7 +195,11 @@ protected:
 private:
     QtDoublePropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtDoublePropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtDoublePropertyManager)
+#else
     Q_DISABLE_COPY(QtDoublePropertyManager)
+#endif
 };
 
 class QtStringPropertyManagerPrivate;
@@ -198,18 +211,18 @@ public:
     ~QtStringPropertyManager() override;
 
     QString value(const QtProperty* property) const;
-    QRegExp regExp(const QtProperty* property) const;
+    QRegularExpression regExp(const QtProperty* property) const;
     EchoMode echoMode(const QtProperty* property) const override;
     bool isReadOnly(const QtProperty* property) const;
 
 public Q_SLOTS:
     void setValue(QtProperty* property, const QString& val);
-    void setRegExp(QtProperty* property, const QRegExp& regExp);
+    void setRegExp(QtProperty* property, const QRegularExpression& regExp);
     void setEchoMode(QtProperty* property, EchoMode echoMode);
     void setReadOnly(QtProperty* property, bool readOnly);
 Q_SIGNALS:
     void valueChanged(QtProperty* property, const QString& val);
-    void regExpChanged(QtProperty* property, const QRegExp& regExp);
+    void regExpChanged(QtProperty* property, const QRegularExpression& regExp);
     void echoModeChanged(QtProperty* property, const int);
     void readOnlyChanged(QtProperty* property, bool);
 protected:
@@ -220,7 +233,11 @@ protected:
 private:
     QtStringPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtStringPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtStringPropertyManager)
+#else
     Q_DISABLE_COPY(QtStringPropertyManager)
+#endif
 };
 
 class QtDatePropertyManagerPrivate;
@@ -250,7 +267,11 @@ protected:
 private:
     QtDatePropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtDatePropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtDatePropertyManager)
+#else
     Q_DISABLE_COPY(QtDatePropertyManager)
+#endif
 };
 
 class QtTimePropertyManagerPrivate;
@@ -274,7 +295,11 @@ protected:
 private:
     QtTimePropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtTimePropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtTimePropertyManager)
+#else
     Q_DISABLE_COPY(QtTimePropertyManager)
+#endif
 };
 
 class QtDateTimePropertyManagerPrivate;
@@ -298,7 +323,11 @@ protected:
 private:
     QtDateTimePropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtDateTimePropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtDateTimePropertyManager)
+#else
     Q_DISABLE_COPY(QtDateTimePropertyManager)
+#endif
 };
 
 class QtKeySequencePropertyManagerPrivate;
@@ -322,7 +351,11 @@ protected:
 private:
     QtKeySequencePropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtKeySequencePropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtKeySequencePropertyManager)
+#else
     Q_DISABLE_COPY(QtKeySequencePropertyManager)
+#endif
 };
 
 class QtCharPropertyManagerPrivate;
@@ -346,7 +379,11 @@ protected:
 private:
     QtCharPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtCharPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtCharPropertyManager)
+#else
     Q_DISABLE_COPY(QtCharPropertyManager)
+#endif
 };
 
 class QtEnumPropertyManager;
@@ -373,7 +410,11 @@ protected:
 private:
     QtLocalePropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtLocalePropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtLocalePropertyManager)
+#else
     Q_DISABLE_COPY(QtLocalePropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotEnumChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -401,7 +442,11 @@ protected:
 private:
     QtPointPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtPointPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtPointPropertyManager)
+#else
     Q_DISABLE_COPY(QtPointPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotIntChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -432,7 +477,11 @@ protected:
 private:
     QtPointFPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtPointFPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtPointFPropertyManager)
+#else
     Q_DISABLE_COPY(QtPointFPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotDoubleChanged(QtProperty*, double))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -466,7 +515,11 @@ protected:
 private:
     QtSizePropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtSizePropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtSizePropertyManager)
+#else
     Q_DISABLE_COPY(QtSizePropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotIntChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -503,7 +556,11 @@ protected:
 private:
     QtSizeFPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtSizeFPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtSizeFPropertyManager)
+#else
     Q_DISABLE_COPY(QtSizeFPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotDoubleChanged(QtProperty*, double))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -534,7 +591,11 @@ protected:
 private:
     QtRectPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtRectPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtRectPropertyManager)
+#else
     Q_DISABLE_COPY(QtRectPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotIntChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -568,7 +629,11 @@ protected:
 private:
     QtRectFPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtRectFPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtRectFPropertyManager)
+#else
     Q_DISABLE_COPY(QtRectFPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotDoubleChanged(QtProperty*, double))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -601,7 +666,11 @@ protected:
 private:
     QtVector3DPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtVector3DPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtVector3DPropertyManager)
+#else
     Q_DISABLE_COPY(QtVector3DPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotDoubleChanged(QtProperty*, double))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -634,7 +703,11 @@ protected:
 private:
     QtEnumPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtEnumPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtEnumPropertyManager)
+#else
     Q_DISABLE_COPY(QtEnumPropertyManager)
+#endif
 };
 
 class QtFlagPropertyManagerPrivate;
@@ -663,7 +736,11 @@ protected:
 private:
     QtFlagPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtFlagPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtFlagPropertyManager)
+#else
     Q_DISABLE_COPY(QtFlagPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotBoolChanged(QtProperty*, bool))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -692,7 +769,11 @@ protected:
 private:
     QtSizePolicyPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtSizePolicyPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtSizePolicyPropertyManager)
+#else
     Q_DISABLE_COPY(QtSizePolicyPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotIntChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotEnumChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
@@ -724,7 +805,11 @@ protected:
 private:
     QtFontPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtFontPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtFontPropertyManager)
+#else
     Q_DISABLE_COPY(QtFontPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotIntChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotEnumChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotBoolChanged(QtProperty*, bool))
@@ -757,7 +842,11 @@ protected:
 private:
     QtColorPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtColorPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtColorPropertyManager)
+#else
     Q_DISABLE_COPY(QtColorPropertyManager)
+#endif
     Q_PRIVATE_SLOT(d_func(), void slotIntChanged(QtProperty*, int))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty*))
 };
@@ -786,7 +875,11 @@ protected:
 private:
     QtCursorPropertyManagerPrivate* d_ptr;
     Q_DECLARE_PRIVATE(QtCursorPropertyManager)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+    Q_DISABLE_COPY_MOVE(QtCursorPropertyManager)
+#else
     Q_DISABLE_COPY(QtCursorPropertyManager)
+#endif
 };
 
 #if QT_VERSION >= 0x040400
