@@ -144,8 +144,7 @@ private:
 };
 
 QtPropertyEditorView::QtPropertyEditorView(QWidget* parent) :
-    QTreeWidget(parent)
-{
+    QTreeWidget(parent) {
     connect(header(), SIGNAL(sectionDoubleClicked(int)), this, SLOT(resizeColumnToContents(int)));
 }
 
@@ -245,9 +244,9 @@ public:
     QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 
     void setModelData(QWidget*, QAbstractItemModel*,
-                      const QModelIndex&) const {}
+                      const QModelIndex&) const override {}
 
-    void setEditorData(QWidget*, const QModelIndex&) const {}
+    void setEditorData(QWidget*, const QModelIndex&) const override {}
 
     bool eventFilter(QObject* object, QEvent* event) override;
     void closeEditor(QtProperty* property);
@@ -341,7 +340,7 @@ QWidget* QtPropertyEditorDelegate::createEditor(QWidget* parent,
 
 void QtPropertyEditorDelegate::updateEditorGeometry(QWidget* editor,
         const QStyleOptionViewItem& option, const QModelIndex& index) const {
-    Q_UNUSED(index)
+    Q_UNUSED(index);
     editor->setGeometry(option.rect.adjusted(0, 0, 0, -1));
 }
 
@@ -424,8 +423,7 @@ bool QtPropertyEditorDelegate::eventFilter(QObject* object, QEvent* event) {
 }
 
 //  -------- QtTreePropertyBrowserPrivate implementation
-QtTreePropertyBrowserPrivate::QtTreePropertyBrowserPrivate()
-{
+QtTreePropertyBrowserPrivate::QtTreePropertyBrowserPrivate() {
 }
 
 // Draw an icon indicating opened/closing branches
@@ -433,7 +431,6 @@ static QIcon drawIndicatorIcon(const QPalette& palette, QStyle* style) {
     QPixmap pix(14, 14);
     pix.fill(Qt::transparent);
     QStyleOption branchOption;
-    QRect r(QPoint(0, 0), pix.size());
     branchOption.rect = QRect(2, 2, 9, 9); // ### hardcoded in qcommonstyle.cpp
     branchOption.palette = palette;
     branchOption.state = QStyle::State_Children;
@@ -459,7 +456,7 @@ static QIcon drawIndicatorIcon(const QPalette& palette, QStyle* style) {
 
 void QtTreePropertyBrowserPrivate::init(QWidget* parent) {
     auto* layout = new QHBoxLayout(parent);
-    layout->setMargin(0);
+    layout->setContentsMargins(QMargins());
     m_treeWidget = new QtPropertyEditorView(parent);
     m_treeWidget->setEditorPrivate(this);
     m_treeWidget->setIconSize(QSize(18, 18));
@@ -576,7 +573,7 @@ void QtTreePropertyBrowserPrivate::propertyInserted(QtBrowserItem* index, QtBrow
     m_indexToItem[index] = newItem;
 
     newItem->setFlags(newItem->flags() | Qt::ItemIsEditable);
-    m_treeWidget->setItemExpanded(newItem, true);
+    newItem->setExpanded(true);
 
     updateItem(newItem);
 }
@@ -867,22 +864,6 @@ void QtTreePropertyBrowser::setResizeMode(QtTreePropertyBrowser::ResizeMode mode
     }
 
     d_ptr->m_resizeMode = mode;
-    QHeaderView::ResizeMode m = QHeaderView::Stretch;
-    switch (mode) {
-        case QtTreePropertyBrowser::Interactive:
-            m = QHeaderView::Interactive;
-            break;
-        case QtTreePropertyBrowser::Fixed:
-            m = QHeaderView::Fixed;
-            break;
-        case QtTreePropertyBrowser::ResizeToContents:
-            m = QHeaderView::ResizeToContents;
-            break;
-        case QtTreePropertyBrowser::Stretch:
-        default:
-            m = QHeaderView::Stretch;
-            break;
-    }
 }
 
 /*!
