@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -93,8 +93,8 @@ QWidget* ActionViewer::getWidget() {
         // add everything to the research frame
         searchFramePanel->setLayout(searchFrameLayout);
         actionWidgetLayout->addWidget(searchFramePanel);
-        // no search panel by default
-        searchFramePanel->setVisible(false);
+        // Search panel active and visible by default
+        setSearchPanelVisible(true);
 
         //-- build the stackedWidget to the action widget layout
         actionWidgetStack = new QStackedWidget();
