@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -193,7 +193,7 @@ QWidget* MedicalImageViewer::getWidget() {
 }
 
 // ---------------------- getPropertyObject ----------------------------
-QObject* MedicalImageViewer::getPropertyObject() {
+PropertyObject* MedicalImageViewer::getPropertyObject() {
     return Application::getViewer("3D Viewer")->getPropertyObject();
 }
 
@@ -300,7 +300,11 @@ void MedicalImageViewer::synchronizeSelection() {
 
 // -------------------- setToolbarAutoVisibility --------------------
 void MedicalImageViewer::setToolbarAutoVisibility(bool toolbarAutoVisibility) {
-    autoUpdateToolbarVisibility = toolbarAutoVisibility;
-    setToolBarVisibility(false);
+    setToolBarVisibility(toolbarAutoVisibility);
 }
 
+// -------------------- setToolBarVisibility --------------------
+void MedicalImageViewer::setToolBarVisibility(bool toolbarVisibility) {
+    autoUpdateToolbarVisibility = toolbarVisibility;
+    Viewer::setToolBarVisibility(toolbarVisibility);
+}
\ No newline at end of file
