@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -86,7 +86,7 @@ public:
     QWidget* getWidget() override;
 
     /// get the propertyObject (only the 3D Scene one)
-    QObject* getPropertyObject() override;
+    camitk::PropertyObject* getPropertyObject() override;
 
     /// get the viewer menu
     QMenu* getMenu() override;
@@ -94,14 +94,20 @@ public:
     /// get the viewer toolbar
     QToolBar* getToolBar() override;
 
-    /** force toolbar visibility.
-     *  The toolbar is normally updated automatically on layout update (see updateLayout()) and is visible
-     *  if all the 3D scene is visible (which is the default visualization state).
-     *  Calling this method with false will avoid this automatic update.
-     *
-     *  By default the toolbar is automatically update
-     */
-    virtual void setToolbarAutoVisibility(bool);
+    /** set the visibility of the toolbar in the main window (true by default).
+      * If the visibility is set to false, the next call to setCentralViewer(..)
+      * or addDockViwer(...) will remove it
+      *
+      * Specific behaviour for MedicalImageViewer:
+      * The toolbar is normally updated automatically on layout update (see updateLayout())
+      * and is visible.
+      *
+      *  if all the 3D scene is visible (which is the default visualization state).
+      *  Calling this method with false will avoid this automatic update.
+      *
+      *  By default the toolbar is automatically updated.
+      */
+    void setToolBarVisibility(bool) override;
     /// @}
 
     /// called to change the layout, i.e. which viewer is visible
@@ -110,6 +116,23 @@ public:
     /// get the current layout value
     LayoutVisibility getVisibleViewer() const;
 
+    ///@cond
+    /**
+     * TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 6.0
+     * @deprecated
+     *
+     * DEPRECATED (CamiTK 6.0) -> to be removed
+     */
+    /** force toolbar visibility.
+     *  The toolbar is normally updated automatically on layout update (see updateLayout()) and is visible
+     *  if all the 3D scene is visible (which is the default visualization state).
+     *  Calling this method with false will avoid this automatic update.
+     *
+     *  By default the toolbar is automatically updated.
+     */
+    CAMITK_API_DEPRECATED("This method is deprecated please use setToolbarVisibility(..) instead") virtual void setToolbarAutoVisibility(bool);
+    ///@endcond
+
 public slots:
     /// called when an internal InteractiveViewers has emitted a selectionChanged signal
     void synchronizeSelection();
