@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -103,7 +103,7 @@ public:
     QWidget* getWidget() override;
 
     /// add a property to change the ObjectController representation at run-time (user choice)
-    QObject* getPropertyObject() override;
+    camitk::PropertyObject* getPropertyObject() override;
     ///@}
 
     ///@name Tab selection management
