@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -43,11 +43,22 @@ TextViewer::TextViewer(QString name) : Viewer(name, Viewer::DOCKED) {
     displayedTopLevelComponents = 0;
     setIcon(QPixmap(":/textviewer"));
     setDescription("This text only viewer displays the number of opened components (docked by default)");
+
+    propertyObject = new PropertyObject(getName());
+    Property* property = new Property("Background Color", QColor(Qt::white), "Text background color, modifiable in the TextViewer settings", "");
+    propertyObject->addProperty(property);
+
+    property = new Property("Text Color", QColor(Qt::blue), "Text color, modifiable in the TextViewer settings", "");
+    propertyObject->addProperty(property);
+
+    // propertyObject is monitored by the TextViewer instance (this) when its properties change
+    propertyObject->installEventFilter(this);
 }
 
 // -------------------- Destructor --------------------
 TextViewer::~TextViewer() {
     delete myWidget;
+    delete propertyObject;
 }
 
 // -------------------- refresh --------------------
@@ -71,10 +82,6 @@ QWidget* TextViewer::getWidget() {
     if (myWidget == nullptr) {
         myWidget = new QWidget();
         output = new QTextEdit();
-        textColor = Qt::blue;
-        bgColor = Qt::white;
-        updateColors();
-
         //-- init layout
         auto* myWidgetLayout = new QHBoxLayout();
         myWidgetLayout->setSpacing(0);
@@ -84,15 +91,16 @@ QWidget* TextViewer::getWidget() {
         myWidgetLayout->addWidget(output);
 
         myWidget->setLayout(myWidgetLayout);
+        updateColors();
     }
 
     return myWidget;
 }
 
 // ---------------------- getPropertyObject ----------------------------
-QObject* TextViewer::getPropertyObject() {
+PropertyObject* TextViewer::getPropertyObject() {
     //  (change the text/background color)
-    return this;
+    return propertyObject;
 }
 
 // -------------------- getMenu --------------------
@@ -102,65 +110,54 @@ QMenu* TextViewer::getMenu() {
         myMenu = new QMenu(objectName());
 
         //-- add the action
-        inverse = new QAction(tr("&Inverse display"), this);
+        inverse = new QAction(tr("&Invert Display"), this);
         inverse->setCheckable(true);
 
-        connect(inverse, SIGNAL(triggered(bool)), this, SLOT(inverseColors(bool)));
+        connect(inverse, SIGNAL(triggered(bool)), this, SLOT(invertColors(bool)));
 
         myMenu->addAction(inverse);
     }
     return myMenu;
 }
 
-// -------------------- inverseColors --------------------
-void TextViewer::inverseColors(bool state) {
-    if (state) {
-        QColor background = output->textBackgroundColor();
-        output->setTextBackgroundColor(output->textColor());
-        output->setTextColor(background);
-        output->append("Inversed colors");
-    }
-    else  {
-        QColor background = output->textBackgroundColor();
-        output->setTextBackgroundColor(output->textColor());
-        output->setTextColor(background);
-        output->append("Normal colors");
-    }
+// -------------------- invertColors --------------------
+void TextViewer::invertColors(bool isInverted) {
+    QColor oldBackgroundColor = propertyObject->property("Background Color").value<QColor>();
+    QColor oldTextColor = propertyObject->property("Text Color").value<QColor>();
+
+    propertyObject->setProperty("Background Color", oldTextColor);
+    propertyObject->setProperty("Text Color", oldBackgroundColor);
+
+    updateColors();
+
+    output->append((isInverted) ? "Inverted colors" : "Normal colors");
 }
 
 // -------------------- updateColors --------------------
 void TextViewer::updateColors() {
-    output->setTextColor(textColor);
-    output->setTextBackgroundColor(bgColor);
+    output->setTextColor(propertyObject->property("Text Color").value<QColor>());
+    output->setTextBackgroundColor(propertyObject->property("Background Color").value<QColor>());
     output->append("Colors updated");
 }
 
+// ---------------- eventFilter ----------------
+bool TextViewer::eventFilter(QObject* object, QEvent* event) {
+    // watch propertyObject instance for dynamic property changes
+    if (event->type() == QEvent::DynamicPropertyChange) {
+        updateColors();
+        return true;
+    }
+    else {
+        // pass the event on to the parent class
+        return Viewer::eventFilter(object, event);
+    }
 
-// -------------------- getBgColor --------------------
-QColor TextViewer::getBgColor() {
-    return bgColor;
 }
 
-// -------------------- getTextColor --------------------
-QColor TextViewer::getTextColor() {
-    return textColor;
-}
-
-// -------------------- setBgColor --------------------
-void TextViewer::setBgColor(QColor c) {
-    bgColor = c;
-    updateColors();
-}
-
-// -------------------- setTextColor --------------------
-void TextViewer::setTextColor(QColor c) {
-    textColor = c;
-    updateColors();
-}
-
-// -------------------- slotEditPreference --------------------
+// -------------------- editPreference --------------------
 void TextViewer::editPreference() {
     SettingsDialog settingsDialog;
-    settingsDialog.editSettings(this);
+    settingsDialog.editSettings(propertyObject);
     settingsDialog.exec();
-}
+    updateColors();
+}
\ No newline at end of file
