@@ -2,7 +2,7 @@
  * $CAMITK_LICENCE_BEGIN$
  *
  * CamiTK - Computer Assisted Medical Intervention ToolKit
- * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
+ * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
  *
  * Visit http://camitk.imag.fr for more information
  *
@@ -31,6 +31,7 @@
 
 // -- Core stuff
 #include <Viewer.h>
+#include <PropertyObject.h>
 
 // -- QT stuff
 #include <QColor>
@@ -46,12 +47,6 @@
 class TEXT_VIEWER_API TextViewer : public camitk::Viewer {
     Q_OBJECT
 
-    /// the background color for the text output
-    Q_PROPERTY(QColor bgColor READ getBgColor WRITE setBgColor)
-
-    /// the forground color for the text ouput
-    Q_PROPERTY(QColor textColor READ getTextColor WRITE setTextColor)
-
 public:
 
     /** @name Constructors/Destructors
@@ -68,32 +63,25 @@ public:
       */
     /// @{
     /// refresh the view (can be interesting to know which other viewer is calling this)
-    virtual void refresh(Viewer* whoIsAsking = nullptr);
+    virtual void refresh(Viewer* whoIsAsking = nullptr) override;
 
     /// get the viewer widget.
-    virtual QWidget* getWidget();
+    virtual QWidget* getWidget() override;
 
     /// get the propertyObject (only the 3D Scene one)
-    virtual QObject* getPropertyObject();
+    virtual camitk::PropertyObject* getPropertyObject() override;
 
     /// get the viewer menu
-    virtual QMenu* getMenu();
-    /// @}
-
-    /** @name Property handling
-      */
-    /// @{
-    QColor getTextColor();
-    void setTextColor(QColor);
-    QColor getBgColor();
-    void setBgColor(QColor);
+    virtual QMenu* getMenu() override;
     /// @}
 
 public slots:
-    /// inverse background/forground colors
-    void inverseColors(bool);
+    /// invert background/foreground colors
+    void invertColors(bool);
 
-    /// this slot should be put in an MainWindow extension, but for simplicity sake for this example, this is here...
+    /// this slot is only used to add a menu item in the textviewer tutorial application
+    /// It creates a SettingsDialog to let the user modify the text/background colors.
+    /// This is not needed in camitk-imp as it manages all viewer properties in the general settings dialog
     void editPreference();
 
 private:
@@ -113,13 +101,17 @@ private:
     /// number of top level component that are currently displayed
     unsigned int displayedTopLevelComponents;
 
-    /// colors
-    QColor textColor;
-    QColor bgColor;
+    /// color properties are defined in the property object (see constructor)
+    camitk::PropertyObject* propertyObject;
 
     /// color management
     void updateColors();
 
+    /**
+     * Event filter of this class instance to watch its properties instances.
+     * Each time a property has dynamically changed, this method is called.
+     */
+    bool eventFilter(QObject* object, QEvent* event) override;
 };
 
 #endif // TEXT_VIEWER_H
